/**
 * \file Per_Task_Task.hh
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date June 2004
 * \brief A Task subclass designed for Per_Task_Consumers.
 **/



// ===================================================================
// Avoid multiple inclusion.
#if !defined (_PER_TASK_TASK_HH)
#define _PER_TASK_TASK_HH
// ===================================================================



// ===================================================================
// INCLUDES

#include "Per_Task_Writer.hh"
#include "Task.hh"
// ===================================================================



// ===================================================================
// CLASS DEFINITION

/**
 * \brief A Task subclass designed for use with Per_Task_Consumer.
 *
 * An extention to the Task class such that it also stores a pointer
 * to a Per_Task_Writer, used by the Per_Task_Consumer to handle the
 * reference stream of each task.
 **/
class Per_Task_Task : public Task {

public:

  /**
   * \brief The constructor.
   *
   * Initialize the task by calling the parent constructor and then
   * setting the writer (which is per-task specific) to null.
   **/
  Per_Task_Task ();

  /**
   * \brief The deconstructor
   *
   * Flush and close the writer.
   **/
  virtual ~Per_Task_Task ();

public: // DATA MEMBERS

  /** \brief A pointer to the output stream writer for this task. */
  Per_Task_Writer* writer;

}; // class Per_Task_Task
// ===================================================================



// ===================================================================
#endif // _PER_TASK_TASK_HH
// ===================================================================
