/**
 * \file Task.cc
 * \author Scott F. H. Kaplan -- sfkaplan@cs.amherst.edu
 * \date June 2004
 * \brief Methods to keep information about a task up-to-date.
 **/



// ===================================================================
// INCLUDES

#include "Process.hh"
#include "Task.hh"
// ===================================================================



// ===================================================================
Task::Task () {

  // Initialize all of the data members to zero/null.
  task_ID = 0;
  process = NULL;
  parent_task = NULL;
  virtual_cycle_time = 0;
  virtual_reference_time = 0;
  last_system_cycle_time = 0;

} // Task::Task
// ===================================================================



// ===================================================================
void
Task::mark_quanta_start (const timestamp_t system_cycle_time) {

  // Bump up the observed global cycle time, but not the virtual cycle
  // time, as this is the beginning of a quanta, and time passed since
  // the last observed system time was due to some other task.
  last_system_cycle_time = system_cycle_time;

} // Task::mark_quanta_start
// ===================================================================



// ===================================================================
void
Task::mark_time (const timestamp_t system_cycle_time,
		 const timestamp_t virtual_reference_time) {

  // How much cycle time has passed since the last call to this
  // method?
  timestamp_t cycle_time_passed =
    system_cycle_time - last_system_cycle_time;

  // Update the virtual cycle time that has passed for this task, as
  // this method is called only during times that this task is
  // scheduled.
  virtual_cycle_time += cycle_time_passed;

  // Bump up the observed system cycle time.
  last_system_cycle_time = system_cycle_time;

  // The reference timestamp is virtual (that is, specific to the
  // reference time that has passed for _this_ task).  Thus, simply
  // assign the reference time provided to this task.  First, though,
  // find the difference in reference time so that the addition can be
  // made to the process reference time.
  timestamp_t reference_time_passed =
    virtual_reference_time - this->virtual_reference_time;
  this->virtual_reference_time = virtual_reference_time;

  // Update the time for this task's process.
  process->mark_time(cycle_time_passed, reference_time_passed);

} // Task::mark_time
// ===================================================================
