#! /bin/tcsh -f

# Check usage.
if (${#argv} != 5) then

    echo "Usage: run-merger.sh <merge type {basic, basic-named, per-task, per-process}>"
    echo "                     <input trace type {v0.4, v0.5}>"
    echo "                     <gzip-compressed reference trace pathname>"
    echo "                     <gzip-compressed kernel trace pathname>"
    echo "                     <output pathname>"
    exit

endif

# Assign names to the command line parameters.
set mergeType = ${argv[1]}
set inputType = ${argv[2]}
set compressedRT = ${argv[3]}
set compressedKT = ${argv[4]}
set outputPathname = ${argv[5]}

# Assign some other useful constants.
set merger = ${HOME}/research/kVMTrace/post-processors/${HOSTTYPE}/merger-0.5.0.2
set RTPipe = /tmp/rt
set KTPipe = /tmp/kt

# Set up the pipes for the input traces.
echo -n "Setting up pipes..."
mkfifo ${RTPipe} ${KTPipe}
gunzip < ${compressedRT} > ${RTPipe} &
gunzip < ${compressedKT} > ${KTPipe} &
echo "done."

# Merge.
echo -n "Merging..."
${merger} ${mergeType} \
	  ${inputType} \
	  ${RTPipe} \
	  ${KTPipe} \
	  ${outputPathname}
echo "done."

# Remove the pipes.
echo -n "Cleaning up pipes..."
rm -f ${RTPipe} ${KTPipe}
echo "done."
