/**
 * \file types-and-constants.cc
 * \author Scott F. H. Kaplan <sfkaplan@cs.amherst.edu>
 * \date August 2004
 * \brief The simple types and constants used in many modules and
 *        classes.
 *
 * This code file contains only the constants themselves.
 **/



// ===================================================================
// INCLUDES

#include "types-and-constants.hh"
#include "Canonical_Page.hh"
// ===================================================================



// ===================================================================
// CONSTANTS

const unsigned int BUFFER_SIZE = 256;
const unsigned int PAGE_SIZE_ORDER = 12;
const unsigned int PAGE_SIZE = (1 << PAGE_SIZE_ORDER);
const unsigned int PAGE_NUMBER_MASK = ~(PAGE_SIZE_ORDER - 1);

Canonical_Page canonical_zero_page(PAGE_TYPE_ANONYMOUS);
Canonical_Page canonical_uncacheable_page(PAGE_TYPE_UNCACHEABLE);

const context_ID_t KERNEL_CONTEXT = 0x101;
const process_ID_t KERNEL_PROCESS_ID = 0;
const virtual_page_ID_t KERNEL_VIRTUAL_PAGE_OFFSET = 0xc0000;
const int NUMBER_POSSIBLE_TAG_VALUES = 1 << (sizeof(tag_t) * 8);
// ===================================================================



// ===================================================================
void
initialize_constants () {

  // These two canonical pages should never be deleted, and so we
  // increment their mapping counts here so that the counts can never
  // (legitimately) reach zero.
  canonical_zero_page.increment_mapping_count();
  canonical_uncacheable_page.increment_mapping_count();

} // initialize_constants
// ===================================================================
